==> acoupi-0.1.0.tar.gz: acoupi-0.1.0/docs/explanation/index.md <==
# Acoupi Explanation

Welcome to the _Explanation Section_ of _acoupi_ package.

This section of the documentation is intended for users who wish to better understand how _acoupi_ has been designed and architected.
The different sections of this _Explanation_ guide will enable you to get a better understanding of the different building blocks forming the _acoupi framework_ and how it is configured and deployed into a running _acoupi application_.

<div class="md-table">
    <table>
        <thead>
            <tr>
                <th>
                    <strong>Explanation Section</strong>
                </th>
                <th>What it is?</th>
            </tr>
        </thead>
        <tbody>
            <tr>
                <td>
                    <a href="Architecture">Architecture</a>
                </td>
                <td>Overview of the architecture supporting the deployment of <i>acoupi</i></td>
            </tr>
            <tr>
                <td>
                    <a href="Data_Schema">Framework</a>
                </td>
                <td>Learn about the different elements of <i>acoupi</i> (data, components, tasks, programs)</td>
            </tr>
            <tr>
                <td>
                <a href="System">System</a>
                </td>
                <td>Understand the inner-workings of a running <i>acoupi</i> application</td>
            </tr>
        </tbody>
    </table>
</div>

!!! info "New to _acoupi_?"

    If you want to get started with _acoupi_, look at the [_Tutorials_](../tutorials/index.md) section providing step-by-step information to help you install, configure, and deploy _acoupi_.

!!! info "How-To guides"

    If you have a specific goal, and are already familiar with _acoupi_, the [_How-to Guides_](../howtoguide/index.md) will have more in-depth detail information to help you tailor _acoupi_ to your personal use case.

!!! info "_acoupi_ Reference"

    Take a look at the [_Reference_](../reference/index.md) section of the documentation to get insights into the python code and learn about the parameters and options available to customise _acoupi_.

==> acoupi-0.3.0.tar.gz: acoupi-0.3.0/docs/explanation/index.md <==
# Acoupi Explanation

Welcome to the _Explanation Section_ of _acoupi_ package.

This section of the documentation is intended for users who wish to better understand how _acoupi_ has been designed and architected.
The different sections of this _Explanation_ guide will enable you to get a better understanding of the different building blocks forming the _acoupi framework_ and how it is configured and deployed into a running _acoupi application_.

<div class="md-table">
    <table>
        <thead>
            <tr>
                <th>
                    <strong>Explanation Section</strong>
                </th>
                <th>What it is?</th>
            </tr>
        </thead>
        <tbody>
            <tr>
                <td>
                    <a href="architecture">Architecture</a>
                </td>
                <td>Overview of the architecture supporting the deployment of <i>acoupi</i></td>
            </tr>
            <tr>
                <td>
                    <a href="data_Schema">Framework</a>
                </td>
                <td>Learn about the different elements of <i>acoupi</i> (data, components, tasks, programs)</td>
            </tr>
            <tr>
                <td>
                <a href="system">System</a>
                </td>
                <td>Understand the inner-workings of a running <i>acoupi</i> application</td>
            </tr>
        </tbody>
    </table>
</div>

!!! info "New to _acoupi_?"

    If you want to get started with _acoupi_, look at the [_Tutorials_](../tutorials/index.md) section providing step-by-step information to help you install, configure, and deploy _acoupi_.

!!! info "How-To guides"

    If you have a specific goal, and are already familiar with _acoupi_, the [_How-to Guides_](../howtoguide/index.md) will have more in-depth detail information to help you tailor _acoupi_ to your personal use case.

!!! info "_acoupi_ Reference"

    Take a look at the [_Reference_](../reference/index.md) section of the documentation to get insights into the python code and learn about the parameters and options available to customise _acoupi_.
